==> nextcloud-22.2.8.tgz: nextcloud/apps/workflowengine/l10n/it.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "L'operatore specificato non è valido",
    "The given regular expression is invalid" : "L'espressione regolare specificata non è valida",
    "The given file size is invalid" : "La dimensione del file specificata non è valida",
    "The given tag id is invalid" : "L'etichetta specificata non è valida",
    "The given IP range is invalid" : "L'intervallo di IP specificato non è valido",
    "The given IP range is not valid for IPv4" : "L'intervallo di IP specificato non è valido per IPv4",
    "The given IP range is not valid for IPv6" : "L'intervallo di IP specificato non è valido per IPv6",
    "The given time span is invalid" : "L'intervallo di tempo specificato non è valido",
    "The given start time is invalid" : "L'ora di inizio specificata non è valida",
    "The given end time is invalid" : "L'ora di fine specificata non è valida",
    "The given group does not exist" : "Il gruppo specificato non esiste",
    "File" : "File",
    "File created" : "File creato",
    "File updated" : "File aggiornato",
    "File renamed" : "File rinominato",
    "File deleted" : "File eliminato",
    "File accessed" : "File acceduto",
    "File copied" : "File copiato",
    "Tag assigned" : "Etichetta assegnata",
    "Someone" : "Qualcuno",
    "%s created %s" : "%s ha creato %s",
    "%s modified %s" : "%s ha modificato %s",
    "%s deleted %s" : "%s ha eliminato %s",
    "%s accessed %s" : "%s ha eseguito l'accesso a %s",
    "%s renamed %s" : "%s ha rinominato %s",
    "%s copied %s" : "%s ha copiato %s",
    "%s assigned %s to %s" : "%s ha assegnato %s a %s",
    "Operation #%s does not exist" : "L'operazione #%s non esiste",
    "Entity %s does not exist" : "L'entità %s non esiste",
    "Entity %s is invalid" : "L'entità %s non è valida",
    "No events are chosen." : "Nessun evento è stato scelto.",
    "Entity %s has no event %s" : "L'entità %s non ha eventi %s",
    "Operation %s does not exist" : "L'operazione %s non esiste",
    "Operation %s is invalid" : "L'operazione %s non è valida",
    "At least one check needs to be provided" : "Deve essere fornito almeno un controllo",
    "The provided operation data is too long" : "I dati operativi forniti sono troppo lunghi",
    "Invalid check provided" : "Controllo fornito non valido ",
    "Check %s does not exist" : "Il controllo %s non esiste",
    "Check %s is invalid" : "Il controllo %s non è valido",
    "Check %s is not allowed with this entity" : "Il controllo di %s non è consentito con questa entità",
    "The provided check value is too long" : "Il valore di controllo fornito è troppo lungo",
    "Check #%s does not exist" : "Il controllo #%s non esiste",
    "Check %s is invalid or does not exist" : "Il controllo %s non è valido o non esiste",
    "Flow" : "Flusso",
    "Nextcloud workflow engine" : "Motore flussi di lavoro di Nextcloud",
    "Select a filter" : "Seleziona un filtro",
    "Select a comparator" : "Seleziona un comparatore",
    "Select a file type" : "Seleziona un tipo di file",
    "e.g. httpd/unix-directory" : "ad es. httpd/unix-directory",
    "Folder" : "Cartella",
    "Images" : "Immagini",
    "Office documents" : "Documenti di Office",
    "PDF documents" : "Documenti PDF",
    "Custom mimetype" : "Tipo MIME personalizzato",
    "Select a tag" : "Seleziona un'etichetta",
    "No results" : "Nessun risultato",
    "%s (invisible)" : "%s (invisibile)",
    "%s (restricted)" : "%s (limitato)",
    "Please enter a valid time span" : "Digita un intervallo temporale valido",
    "Select a request URL" : "Seleziona un URL di richiesta",
    "Predefined URLs" : "URL predefiniti",
    "Files WebDAV" : "File WebDAV",
    "Others" : "Altri",
    "Custom URL" : "URL personalizzato",
    "Select a user agent" : "Seleziona user agent",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client desktop",
    "Thunderbird & Outlook addons" : "Componenti aggiuntivi di Outlook e Thunderbird",
    "Custom user agent" : "User agent personalizzato",
    "At least one event must be selected" : "Deve essere selezionato almeno un evento",
    "Add new flow" : "Aggiungi nuovo flusso",
    "When" : "Quando",
    "and" : "e",
    "Cancel" : "Annulla",
    "Delete" : "Elimina",
    "The configuration is invalid" : "La configurazione non è valida",
    "Active" : "Attivo",
    "Save" : "Salva",
    "Available flows" : "Flussi disponibili",
    "For details on how to write your own flow, check out the development documentation." : "Per dettagli su come scrivere il tuo flusso, controlla la documentazione di sviluppo.",
    "More flows" : "Altri flussi",
    "Browse the App Store" : "Sfoglia il negozio delle applicazioni",
    "Show less" : "Mostra meno",
    "Show more" : "Mostra più",
    "Configured flows" : "Flussi configurati",
    "Your flows" : "I tuoi flussi",
    "matches" : "corrisponde",
    "does not match" : "non corrisponde",
    "is" : "è",
    "is not" : "non è",
    "File name" : "Nome file",
    "File MIME type" : "Tipo MIME del file",
    "File size (upload)" : "Dimensione file (caricamento)",
    "less" : "minore",
    "less or equals" : "minore o uguale",
    "greater or equals" : "maggiore o uguale",
    "greater" : "maggiore",
    "Request remote address" : "Indirizzo remoto della richiesta",
    "matches IPv4" : "corrisponde a IPv4",
    "does not match IPv4" : "non corrisponde a IPv4",
    "matches IPv6" : "corrisponde a IPv6",
    "does not match IPv6" : "non corrisponde a IPv6",
    "File system tag" : "Etichetta del file system",
    "is tagged with" : "è etichettato con",
    "is not tagged with" : "non è etichettato con",
    "Request URL" : "URL della richiesta",
    "Request time" : "Ora della richiesta",
    "between" : "compreso",
    "not between" : "non compreso",
    "Request user agent" : "User agent della richiesta",
    "User group membership" : "Appartenenza ai gruppi degli utenti",
    "is member of" : "è membro di",
    "is not member of" : "non è membro di"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/workflowengine/l10n/it.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "L'operatore specificato non è valido",
    "The given regular expression is invalid" : "L'espressione regolare specificata non è valida",
    "The given file size is invalid" : "La dimensione del file specificata non è valida",
    "The given tag id is invalid" : "L'etichetta specificata non è valida",
    "The given IP range is invalid" : "L'intervallo di IP specificato non è valido",
    "The given IP range is not valid for IPv4" : "L'intervallo di IP specificato non è valido per IPv4",
    "The given IP range is not valid for IPv6" : "L'intervallo di IP specificato non è valido per IPv6",
    "The given time span is invalid" : "L'intervallo di tempo specificato non è valido",
    "The given start time is invalid" : "L'ora di inizio specificata non è valida",
    "The given end time is invalid" : "L'ora di fine specificata non è valida",
    "The given group does not exist" : "Il gruppo specificato non esiste",
    "File" : "File",
    "File created" : "File creato",
    "File updated" : "File aggiornato",
    "File renamed" : "File rinominato",
    "File deleted" : "File eliminato",
    "File accessed" : "File acceduto",
    "File copied" : "File copiato",
    "Tag assigned" : "Etichetta assegnata",
    "Someone" : "Qualcuno",
    "%s created %s" : "%s ha creato %s",
    "%s modified %s" : "%s ha modificato %s",
    "%s deleted %s" : "%s ha eliminato %s",
    "%s accessed %s" : "%s ha eseguito l'accesso a %s",
    "%s renamed %s" : "%s ha rinominato %s",
    "%s copied %s" : "%s ha copiato %s",
    "%s assigned %s to %s" : "%s ha assegnato %s a %s",
    "Operation #%s does not exist" : "L'operazione #%s non esiste",
    "Entity %s does not exist" : "L'entità %s non esiste",
    "Entity %s is invalid" : "L'entità %s non è valida",
    "No events are chosen." : "Nessun evento è stato scelto.",
    "Entity %s has no event %s" : "L'entità %s non ha eventi %s",
    "Operation %s does not exist" : "L'operazione %s non esiste",
    "Operation %s is invalid" : "L'operazione %s non è valida",
    "At least one check needs to be provided" : "Deve essere fornito almeno un controllo",
    "The provided operation data is too long" : "I dati operativi forniti sono troppo lunghi",
    "Invalid check provided" : "Controllo fornito non valido ",
    "Check %s does not exist" : "Il controllo %s non esiste",
    "Check %s is invalid" : "Il controllo %s non è valido",
    "Check %s is not allowed with this entity" : "Il controllo di %s non è consentito con questa entità",
    "The provided check value is too long" : "Il valore di controllo fornito è troppo lungo",
    "Check #%s does not exist" : "Il controllo #%s non esiste",
    "Check %s is invalid or does not exist" : "Il controllo %s non è valido o non esiste",
    "Flow" : "Flusso",
    "Nextcloud workflow engine" : "Motore flussi di lavoro di Nextcloud",
    "Select a filter" : "Seleziona un filtro",
    "Select a comparator" : "Seleziona un comparatore",
    "Select a file type" : "Seleziona un tipo di file",
    "e.g. httpd/unix-directory" : "ad es. httpd/unix-directory",
    "Folder" : "Cartella",
    "Images" : "Immagini",
    "Office documents" : "Documenti di Office",
    "PDF documents" : "Documenti PDF",
    "Custom mimetype" : "Tipo MIME personalizzato",
    "Select a tag" : "Seleziona un'etichetta",
    "No results" : "Nessun risultato",
    "%s (invisible)" : "%s (invisibile)",
    "%s (restricted)" : "%s (limitato)",
    "Please enter a valid time span" : "Digita un intervallo temporale valido",
    "Select a request URL" : "Seleziona un URL di richiesta",
    "Predefined URLs" : "URL predefiniti",
    "Files WebDAV" : "File WebDAV",
    "Others" : "Altri",
    "Custom URL" : "URL personalizzato",
    "Select a user agent" : "Seleziona user agent",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client desktop",
    "Thunderbird & Outlook addons" : "Componenti aggiuntivi di Outlook e Thunderbird",
    "Custom user agent" : "User agent personalizzato",
    "At least one event must be selected" : "Deve essere selezionato almeno un evento",
    "Add new flow" : "Aggiungi nuovo flusso",
    "When" : "Quando",
    "and" : "e",
    "Cancel" : "Annulla",
    "Delete" : "Elimina",
    "The configuration is invalid" : "La configurazione non è valida",
    "Active" : "Attivo",
    "Save" : "Salva",
    "Available flows" : "Flussi disponibili",
    "For details on how to write your own flow, check out the development documentation." : "Per dettagli su come scrivere il tuo flusso, controlla la documentazione di sviluppo.",
    "More flows" : "Altri flussi",
    "Browse the App Store" : "Sfoglia il negozio delle applicazioni",
    "Show less" : "Mostra meno",
    "Show more" : "Mostra più",
    "Configured flows" : "Flussi configurati",
    "Your flows" : "I tuoi flussi",
    "matches" : "corrisponde",
    "does not match" : "non corrisponde",
    "is" : "è",
    "is not" : "non è",
    "File name" : "Nome file",
    "File MIME type" : "Tipo MIME del file",
    "File size (upload)" : "Dimensione file (caricamento)",
    "less" : "minore",
    "less or equals" : "minore o uguale",
    "greater or equals" : "maggiore o uguale",
    "greater" : "maggiore",
    "Request remote address" : "Indirizzo remoto della richiesta",
    "matches IPv4" : "corrisponde a IPv4",
    "does not match IPv4" : "non corrisponde a IPv4",
    "matches IPv6" : "corrisponde a IPv6",
    "does not match IPv6" : "non corrisponde a IPv6",
    "File system tag" : "Etichetta del file system",
    "is tagged with" : "è etichettato con",
    "is not tagged with" : "non è etichettato con",
    "Request URL" : "URL della richiesta",
    "Request time" : "Ora della richiesta",
    "between" : "compreso",
    "not between" : "non compreso",
    "Request user agent" : "User agent della richiesta",
    "User group membership" : "Appartenenza ai gruppi degli utenti",
    "is member of" : "è membro di",
    "is not member of" : "non è membro di"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
